==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_functions/mp0038_001/MP0038_SyncActivity_001.java <==

package net.datastream.schemas.mp_functions.mp0038_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.activity_001.Activity;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Activity_001}Activity"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Activity" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="SyncActivity" />
 *       &lt;attribute name="confirmadddeletechecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmcleartaskreference" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmReDispatchEmployees" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "activity"
})
@XmlRootElement(name = "MP0038_SyncActivity_001")
public class MP0038_SyncActivity_001 {

    @XmlElement(name = "Activity", namespace = "http://schemas.datastream.net/MP_entities/Activity_001", required = true)
    protected Activity activity;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "confirmadddeletechecklist")
    protected String confirmadddeletechecklist;
    @XmlAttribute(name = "confirmcleartaskreference")
    protected String confirmcleartaskreference;
    @XmlAttribute(name = "confirmReDispatchEmployees")
    protected String confirmReDispatchEmployees;

    /**
     * Obtient la valeur de la propriété activity.
     * 
     * @return
     *     possible object is
     *     {@link Activity }
     *     
     */
    public Activity getActivity() {
        return activity;
    }

    /**
     * Définit la valeur de la propriété activity.
     * 
     * @param value
     *     allowed object is
     *     {@link Activity }
     *     
     */
    public void setActivity(Activity value) {
        this.activity = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.ACTIVITY;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété callname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "SyncActivity";
        } else {
            return callname;
        }
    }

    /**
     * Définit la valeur de la propriété callname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Obtient la valeur de la propriété confirmadddeletechecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmadddeletechecklist() {
        if (confirmadddeletechecklist == null) {
            return "prompt";
        } else {
            return confirmadddeletechecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmadddeletechecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmadddeletechecklist(String value) {
        this.confirmadddeletechecklist = value;
    }

    /**
     * Obtient la valeur de la propriété confirmcleartaskreference.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmcleartaskreference() {
        if (confirmcleartaskreference == null) {
            return "prompt";
        } else {
            return confirmcleartaskreference;
        }
    }

    /**
     * Définit la valeur de la propriété confirmcleartaskreference.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmcleartaskreference(String value) {
        this.confirmcleartaskreference = value;
    }

    /**
     * Obtient la valeur de la propriété confirmReDispatchEmployees.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmReDispatchEmployees() {
        if (confirmReDispatchEmployees == null) {
            return "prompt";
        } else {
            return confirmReDispatchEmployees;
        }
    }

    /**
     * Définit la valeur de la propriété confirmReDispatchEmployees.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmReDispatchEmployees(String value) {
        this.confirmReDispatchEmployees = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/mp0038_001/MP0038_SyncActivity_001.java <==

package net.datastream.schemas.mp_functions.mp0038_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.activity_001.Activity;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Activity_001}Activity"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Activity" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="SyncActivity" />
 *       &lt;attribute name="confirmadddeletechecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmcleartaskreference" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmReDispatchEmployees" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "activity"
})
@XmlRootElement(name = "MP0038_SyncActivity_001")
public class MP0038_SyncActivity_001 {

    @XmlElement(name = "Activity", namespace = "http://schemas.datastream.net/MP_entities/Activity_001", required = true)
    protected Activity activity;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "confirmadddeletechecklist")
    protected String confirmadddeletechecklist;
    @XmlAttribute(name = "confirmcleartaskreference")
    protected String confirmcleartaskreference;
    @XmlAttribute(name = "confirmReDispatchEmployees")
    protected String confirmReDispatchEmployees;

    /**
     * Gets the value of the activity property.
     * 
     * @return
     *     possible object is
     *     {@link Activity }
     *     
     */
    public Activity getActivity() {
        return activity;
    }

    /**
     * Sets the value of the activity property.
     * 
     * @param value
     *     allowed object is
     *     {@link Activity }
     *     
     */
    public void setActivity(Activity value) {
        this.activity = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.ACTIVITY;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "SyncActivity";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Gets the value of the confirmadddeletechecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmadddeletechecklist() {
        if (confirmadddeletechecklist == null) {
            return "prompt";
        } else {
            return confirmadddeletechecklist;
        }
    }

    /**
     * Sets the value of the confirmadddeletechecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmadddeletechecklist(String value) {
        this.confirmadddeletechecklist = value;
    }

    /**
     * Gets the value of the confirmcleartaskreference property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmcleartaskreference() {
        if (confirmcleartaskreference == null) {
            return "prompt";
        } else {
            return confirmcleartaskreference;
        }
    }

    /**
     * Sets the value of the confirmcleartaskreference property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmcleartaskreference(String value) {
        this.confirmcleartaskreference = value;
    }

    /**
     * Gets the value of the confirmReDispatchEmployees property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmReDispatchEmployees() {
        if (confirmReDispatchEmployees == null) {
            return "prompt";
        } else {
            return confirmReDispatchEmployees;
        }
    }

    /**
     * Sets the value of the confirmReDispatchEmployees property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmReDispatchEmployees(String value) {
        this.confirmReDispatchEmployees = value;
    }

}
